markuptools.MarkupCommand
=========================

.. inheritance-diagram:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand
   :private-bases:

.. autoclass:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.args

.. autoattribute:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.command

.. autoattribute:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.format

Special Methods
---------------

.. automethod:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.__eq__

.. automethod:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.__repr__

.. automethod:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.__str__
